@@ -1,4 +1,4 @@
 from LsBook.lsbook import main
 
 if __name__ == '__main__':
-    main()
+    main(True)
